.. GeneWalk documentation master file, created by
   sphinx-quickstart on Tue Feb  5 17:23:03 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

GeneWalk documentation
======================

.. toctree::
   :maxdepth: 3

   modules/index



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
